@@ -5,6 +5,7 @@ use Kelp::Base 'Plack::Response';
 use Encode;
 use Carp;
 use Try::Tiny;
+use Scalar::Util;
 
 attr -app => sub { croak "app is required" };
 attr rendered => 0;
@@ -120,6 +121,7 @@ sub render_error {
 
     # Look for a template and if not found, then show a generic text
     try {
+        local $SIG{__DIE__};  # Silence StackTrace
         my $filename = "error/$code";
         $self->template(
             $filename, {
@@ -140,17 +142,16 @@ sub render_404 {
 }
 
 sub render_500 {
-    my ( $self, $message ) = @_;
-    if ( $self->app->mode ne 'deployment' ) {
-        if ($message) {
-            return $self->set_code(500)->render($message);
-        }
-        else {
-            local $SIG{__DIE__};    # Silence StackTrace
-            return $self->render_error( 500, $message );
-        }
+    my ( $self, $error ) = @_;
+
+    if ( !defined $error || $self->app->mode eq 'deployment' ) {
+        return $self->render_error;
     }
-    $self->render_error;
+
+    # if render_500 gets blessed object as error stringify it
+    $error = ref $error if Scalar::Util::blessed $error;
+    
+    return $self->set_code(500)->render($error);
 }
 
 sub render_401 {
